@@ -3,6 +3,7 @@ import copy
 import logging
 import os
 import re
+import shutil
 import tempfile
 from dataclasses import dataclass
 from typing import Any, Dict, List, Optional, Pattern, Tuple
@@ -45,7 +46,6 @@ GIT_DIFF_ARGS = [
     "--full-index",
     "--no-color",
     "--no-textconv",
-    "--binary",
     "-U1",
 ]
 
@@ -131,8 +131,11 @@ def is_commit_hash(commit_ish: GitCommitHash) -> bool:
     return re.match(RE_COMMIT_HASH, commit_ish) is not None
 
 
-async def get_default_git(sh: shell.Shell) -> str:
-    return (await sh.sh("/usr/bin/which", "git"))[1].strip()
+def get_default_git() -> str:
+    ret = shutil.which("git")
+    if not ret:
+        raise RevupUsageException("Could not find a 'git' binary on the current PATH.")
+    return ret
 
 
 async def make_git(
@@ -146,7 +149,7 @@ async def make_git(
     editor: str = "",
 ) -> "Git":
     if not git_path:
-        git_path = await get_default_git(sh)
+        git_path = get_default_git()
 
     git_ctx = Git(sh, git_path, remote_name, main_branch, base_branch_globs, keep_temp)
 
@@ -403,10 +406,10 @@ class Git:
         return branch[len(f"{self.remote_name}/") :]
 
     async def find_remote_branches(
-        self, limit_to_base_branches: bool, prune_old: bool
+        self, commit: str, limit_to_base_branches: bool, prune_old: bool
     ) -> List[str]:
         """
-        Finds all remote branches that are candidates for auto-detected base branch.
+        Finds all branches that are candidates for auto-detected base branch of the given commit.
         Optionally, limit_to_base_branches will only select those branches which match
         a branch naming glob given in the config.
         prune_old will discard invalid branches to speed up the selection process.
@@ -414,8 +417,18 @@ class Git:
         """
         args = ["--format", "%(refname)"]
 
+        if limit_to_base_branches:
+            if not self.base_branch_globs:
+                return [f"{self.remote_name}/{self.main_branch}"]
+            args.append(f"refs/remotes/{self.remote_name}/{self.main_branch}")
+            for b in self.base_branch_globs:
+                args.append(f"refs/remotes/{self.remote_name}/" + b)
+        else:
+            args.append(f"refs/remotes/{self.remote_name}/{self.main_branch}")
+            args.append(f"refs/remotes/{self.remote_name}/*")
+
         if prune_old:
-            fork_with_main = await self.fork_point("HEAD", f"{self.remote_name}/{self.main_branch}")
+            fork_with_main = await self.fork_point(commit, f"{self.remote_name}/{self.main_branch}")
             # A branch that doesn't contain the fork with main must be too old
             args.extend(
                 (
@@ -424,14 +437,6 @@ class Git:
                 )
             )
 
-        if limit_to_base_branches:
-            args.append(f"refs/remotes/{self.remote_name}/{self.main_branch}")
-            for b in self.base_branch_globs:
-                args.append(f"refs/remotes/{self.remote_name}/" + b)
-        else:
-            args.append(f"refs/remotes/{self.remote_name}/{self.main_branch}")
-            args.append(f"refs/remotes/{self.remote_name}/*")
-
         RE_REMOTE_REF = re.compile(r"^refs/remotes/(?P<branch>.*)$")
         ret: List[str] = []
         for ref in (await self.git_stdout("for-each-ref", *args)).split("\n"):
@@ -441,16 +446,22 @@ class Git:
         return ret
 
     async def get_best_base_branch_candidates(
-        self, commit: str, limit_to_base_branches: bool = True
+        self, commit: str, limit_to_base_branches: bool = True, allow_self: bool = True
     ) -> List[str]:
         """
         Find the best base branch for the current HEAD by listing candidate remote branches
         Return the branch(es) with the shortest distance from HEAD to fork-point
         """
-        branches = await self.find_remote_branches(limit_to_base_branches, True)
+        branches = await self.find_remote_branches(commit, limit_to_base_branches, True)
         candidates: List[Tuple[int, str]] = []
 
+        if len(branches) == 1:
+            return branches
+
         for b in branches:
+            if not allow_self and b == commit:
+                continue
+
             # If we have valid candidates, we can stop iterating once the distance is greater
             # than the current best distance.
             dist = await self.distance_to_fork_point(
@@ -463,12 +474,19 @@ class Git:
                 candidates.append((dist, b))
         return [c[1] for c in candidates]
 
-    async def get_best_base_branch(self, commit: str, limit_to_base_branches: bool = True) -> str:
+    async def get_best_base_branch(
+        self,
+        commit: str,
+        limit_to_base_branches: bool = True,
+        allow_self: bool = True,
+    ) -> str:
         """
         If the current branch or main is among the best branches, choose that.
         Otherwise choose the last lexographically.
         """
-        candidates = await self.get_best_base_branch_candidates(commit, limit_to_base_branches)
+        candidates = await self.get_best_base_branch_candidates(
+            commit, limit_to_base_branches, allow_self
+        )
         ret = candidates[0]
         if len(candidates) == 1:
             return ret
@@ -570,7 +588,7 @@ class Git:
         git_env = {
             "GIT_INDEX_FILE": temp_index_path,
         }
-        await self.sh.sh("cp", f"{self.git_dir}/index", temp_index_path)
+        shutil.copy(f"{self.git_dir}/index", temp_index_path)
         await self.git("reset", "-q", "--no-refresh", parent_tree, "--", ":/", env=git_env)
         success = not (
             await self.sh.piped_sh(
@@ -686,7 +704,7 @@ class Git:
         git_env = {
             "GIT_INDEX_FILE": temp_index_path,
         }
-        await self.sh.sh("cp", f"{self.git_dir}/index", temp_index_path)
+        shutil.copy(f"{self.git_dir}/index", temp_index_path)
         await self.git("reset", "-q", "--no-refresh", new_base, "--", ":/", env=git_env)
         await self.git(
             "update-index",
