@@ -217,6 +217,9 @@ class TopicStack:
     # All virtual diff targets for the current upload are chained into a dummy branch
     last_virtual_diff_target: Optional[GitCommitHash] = None
 
+    # Whether populate() was successfully called
+    populated: bool = False
+
     def all_reviews_iter(self) -> Iterator[Tuple[str, Topic, str, Review]]:
         """
         One liner for common iteration pattern to reduce indentation a bit.
@@ -323,12 +326,13 @@ class TopicStack:
             diff = "rebase"
             summary = "0 files changed"
 
+        d = datetime.now()
         ret += (
             f"\r\n| {number} | [{review.new_commits[-1][:8]}]"
             f"(/{self.fork_info.owner}/{self.repo_info.name}/commit/{review.new_commits[-1]}) "
             f"| [{review.base_ref[:8]}]"
             f"(/{self.fork_info.owner}/{self.repo_info.name}/commit/{review.base_ref}) "
-            f"| {diff} | {datetime.today().strftime('%b %d %-I:%M %p')} | {summary} |"
+            f"| {diff} | {d:%b} {d.day} {d.hour}:{d.minute:02} {d:%p} | {summary} |"
         )
         return PrComment(ret, orig.id if orig else None)
 
@@ -340,6 +344,8 @@ class TopicStack:
         """
         Parse all commits and sort them into individual topics.
         """
+        if self.populated:
+            return
         if self.base_branch:
             self.base_branch = self.git_ctx.ensure_branch_prefix(self.base_branch)
             await self.git_ctx.verify_branch_or_commit(self.base_branch)
@@ -372,9 +378,6 @@ class TopicStack:
             await self.git_ctx.rev_list("HEAD", branch_point, header=True, first_parent=True)
         )
 
-        if len(self.commits) == 0:
-            raise RevupUsageException(f"No changes from branch {self.relative_branch}")
-
         # Parse tags and add each commit to appropriate topics
         for c in self.commits:
             parsed_tags, trimmed_msg = self.parse_commit_tags(c.commit_msg)
@@ -401,9 +404,7 @@ class TopicStack:
                     self.topics[name] = Topic(name)
                 self.topics[name].original_commits.append(c)
                 add_tags(self.topics[name].tags, parsed_tags)
-
-        if len(self.topics) == 0:
-            raise RevupUsageException(f"Found {len(self.commits)} commits but no topic tags!")
+        self.populated = True
 
     async def populate_reviews(
         self,
@@ -918,6 +919,7 @@ class TopicStack:
                 "push",
                 "--force",
                 "--no-verify",
+                "--atomic",
                 "--quiet" if self.git_ctx.sh.quiet else "--verbose",
                 self.git_ctx.remote_name,
                 *push_targets,
